import echo from '#start';
import cluster from 'cluster';
import os from 'os';
import Application from './application.js';

// 获取 CPU 核心数
const numCPUs = os.cpus().length;

function sleep(time = 1000) {
    return new Promise(resolve => {
        setTimeout(() => {
            resolve();
        }, time);
    });
}

// 启动集群
async function clusterStart() {
    // 检查是否为主进程
    if (cluster.isPrimary) {
        echo();
        // 设置负载均衡策略
        cluster.schedulingPolicy = cluster.SCHED_RR;
        console.log(`Primary ${process.pid} is running`);
        if (process.env.NODE_ENV === 'production') {
            console.log('>>>>>>>>>>>>>>多线程模式');
            // 为每个 CPU 核心创建一个工作进程
            for (let i = 0; i < /*numCPUs*/ 2; i++) {
                const worker = cluster.fork();
                worker.on('message', async message => {
                    if (message.type === 'workerStarted') {
                        worker.send({ type: 'workerId', id: i + 1 });
                    }
                });
                await sleep(100);
            }
            // 监听工作进程退出事件
            cluster.on('exit', (worker, code, signal) => {
                console.log(`Worker ${worker.process.pid} died`);
            });
        } else {
            console.log('==============单线程模式');
            Application();
        }
    } else {
        // 工作进程
        // 告诉主进程工作进程已启动
        process.send({ type: 'workerStarted', pid: process.pid });
        // 监听主进程发送的消息
        process.on('message', message => {
            if (message.type === 'workerId') {
                const workerId = message.id;
                console.log(
                    `Worker (ID ${workerId.toString().padStart(2, 0)}) ${process.pid.toString().padEnd(8, ' ')} started`,
                );
                // 启动服务器
                Application(workerId);
            }
        });
    }
}

clusterStart();
