import fastifyPlugin from 'fastify-plugin';
function errorHandler(fastify) {
    // 添加 404 处理器 (关键修改)
    fastify.setNotFoundHandler((request, reply) => {
        const error = new Error(`路由 ${request.url} 不存在`);
        error.code = 'ROUTE_NOT_FOUND';
        error.statusCode = 404;
        return reply.code(404).send(error);
    });

    fastify.setErrorHandler((error, request, reply) => {
        // 记录原始错误
        // fastify.log.error(`[ErrorHandler] ${error.message}`, error);

        console.log('AAAA1validation', error.validation);
        console.log('AAAA2statusCode', error.statusCode);
        console.log('AAAA3code', error.code);
        console.log('AAAA4message', error.message);

        // 保留AJV验证错误处理
        if (error.validation) {
            // 没有请求体
            const bodyError = error.validation.find(
                e =>
                    e.keyword === 'type' ||
                    (e.keyword === 'required' && e.validationContext == 'body'),
            );

            if (bodyError) {
                return reply.code(400).send({
                    code: error.statusCode,
                    codeString: error.code,
                    error: `请求体不能为空，请提供有效的JSON数据！`,
                    details: error.validation,
                });
            }else{
                return reply.code(400).send({
                    code: error.statusCode,
                    codeString: error.code,
                    error: error.message,
                    details: error.validation,
                });
            }
        }

        // 使用sensible的HTTP错误处理
        if (error.statusCode && error.statusCode >= 400) {
            return reply.code(error.statusCode).send({
                code: error.statusCode,
                codeString: error.code,
                error: error.message,
                ...(error.details && { details: error.details }),
            });
        }

        // 最终未处理错误（生产环境隐藏细节）
        const isProduction = process.env.NODE_ENV === 'production';
        reply.code(500).send({
            code: '500',
            error: isProduction ? '服务器内部错误' : error.message,
            ...(!isProduction && { stack: error.stack }),
        });
    });
}
export default fastifyPlugin(errorHandler);
