import fp from 'fastify-plugin';
import database from '#plugins/database/index';
import swagger from '#plugins/swagger/index';
import errorHandler from '#plugins/error/errorHandler';
import encryption from '#plugins/encryption/index';
import snowflake from '#plugins/snowflake/index';
import redis from '#plugins/redis/index';
import conseData from '#plugins/const/index';

async function plugin(fastify, opts) {
    fastify.log.warn('Register Global Plugin!');
    // 加载配置
    fastify.decorate('config', opts.config);
    // 注册数据库
    await fastify.register(database);
    // 注册redis
    await fastify.register(redis);
    // 注册swagger
    fastify.config.env === 'development' && (await fastify.register(swagger));
    // 注册加密工具
    await fastify.register(encryption);
    // 注册雪花ID
    await fastify.register(snowflake);
    // 注册常量
    await fastify.register(conseData);
    // 注册错误处理工具
    await fastify.register(import('@fastify/sensible'));
    fastify.register(errorHandler);

    fastify.log.warn('Register Global Plugin complete!');
}
export default fp(plugin);
